@@ -1,6 +1,7 @@
 package App::skryf::Command::newpage;
 
-use strictures 1;
+use strict;
+use warnings;
 use v5.16;
 use FindBin '$Bin';
 use Mojo::Base 'Mojolicious::Command';
@@ -8,8 +9,6 @@ use Path::Tiny;
 use DateTime;
 use App::skryf::Util;
 
-our $VERSION = '0.005_04'; # VERSION
-
 has description => "Create a new static page.\n";
 has usage => <<"EOF";
 Usage: $0 newpage page-name
